make_date_url: This function generates the url depending on the exchange and...

Description Usage Arguments Value Examples

Description

Generate url to download

Usage

1
make_date_url(date, exchange = c("nse", "bse"))

Arguments

date

The date you want the data for. The input should either be a date object or a something that lubridate::as_date can parse to be a date. If a string is in the format yyyy-mm-dd, this generally works.

exchange

Choose either "bse" or "nse". If nothing is provided, defaults to "nse".

Value

The url that should have the data for the exchange and the date specified.

Examples

1
2
3
IndianStocksR:::make_date_url("2018-07-25", exchange = "bse")

IndianStocksR:::make_date_url(lubridate::today())

ilangurudev/IndianStocksR documentation built on May 12, 2019, 4:36 a.m.