Description Usage Arguments Value Examples
Generate url to download
1 | make_date_url(date, exchange = c("nse", "bse"))
|
date |
The date you want the data for. The input should either be a date object or a something that lubridate::as_date can parse to be a date. If a string is in the format yyyy-mm-dd, this generally works. |
exchange |
Choose either "bse" or "nse". If nothing is provided, defaults to "nse". |
The url that should have the data for the exchange and the date specified.
1 2 3 | IndianStocksR:::make_date_url("2018-07-25", exchange = "bse")
IndianStocksR:::make_date_url(lubridate::today())
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.